@@ -27,11 +27,4 @@ def add_info(report):
     report['DisplayManager'] = result
 
     HOME = os.path.expanduser("~")
-    attach_file_if_exists(report, HOME+'/.cache/upstart/gnome-session.log',key='gnomeSessionLog')
-    if result == 'gdm':
-        attach_file_if_exists(report, HOME+'/.cache/gdm/session.log',key='gdmSessionLog')
-    else:   
-        attach_file_if_exists(report, HOME+'/.xsession-errors',key='XsessionLog')
-
-
-	
+    attach_file_if_exists(report, HOME+'/.cache/upstart/gnome-session-gnome.log',key='gnomeSessionLog')
